@@ -31,14 +31,16 @@
 #include <config.h>
 #endif
 
+#include <string.h> /* For strlen */
+
 #include <glib/gutils.h>
 #include <libgnome/gnome-i18n.h>
 
-#include <gedit-menus.h>
-#include <gedit-plugin.h>
-#include <gedit-debug.h>
+#include <gedit/gedit-menus.h>
+#include <gedit/gedit-plugin.h>
+#include <gedit/gedit-debug.h>
 
-#define MENU_ITEM_LABEL		N_("Insert User _Name")
+#define MENU_ITEM_LABEL		N_("Insert User Na_me")
 #define MENU_ITEM_PATH		"/menu/Edit/EditOps_4/"
 #define MENU_ITEM_NAME		"UserName"	
 #define MENU_ITEM_TIP		N_("Insert the user name at the cursor position")
@@ -54,27 +56,45 @@ static void
 sample_cb (BonoboUIComponent *uic, gpointer user_data, const gchar* verbname)
 {
 	GeditDocument *doc;
-	GeditView *view;
-	gchar* user_name;
-	
+	gchar *user_name;
+	gchar *user_name_utf8;
+	const gchar *temp;
+
 	gedit_debug (DEBUG_PLUGINS, "");
 
-	view = gedit_get_active_view ();
-	g_return_if_fail (view != NULL);
-	
-	doc = gedit_view_get_document (view);
+	doc = gedit_get_active_document ();
 	g_return_if_fail (doc != NULL);
 
-	user_name = g_strdup_printf ("%s ", g_get_real_name ());
+	temp = g_get_real_name ();
+	g_return_if_fail (temp != NULL);
+	
+	if (strlen (temp) <= 0)
+	{
+		temp = g_get_user_name ();
+		g_return_if_fail (temp != NULL);
+	}
+	
+	user_name = g_strdup_printf ("%s ", temp);
 	g_return_if_fail (user_name != NULL);
 
+	if (g_utf8_validate (user_name, -1, NULL))
+		user_name_utf8 = user_name;
+	else
+	{
+		user_name_utf8 = g_locale_to_utf8 (user_name, -1, NULL, NULL, NULL);
+		g_free (user_name);
+
+		if (user_name_utf8 == NULL)
+			user_name_utf8 = g_strdup (" ");
+	}
+
 	gedit_document_begin_user_action (doc);
 	
-	gedit_document_insert_text_at_cursor (doc, user_name, -1);
+	gedit_document_insert_text_at_cursor (doc, user_name_utf8, -1);
 
 	gedit_document_end_user_action (doc);
 
-	g_free (user_name);
+	g_free (user_name_utf8);
 }
 
 G_MODULE_EXPORT GeditPluginState
@@ -82,16 +102,20 @@ update_ui (GeditPlugin *plugin, BonoboWindow *window)
 {
 	BonoboUIComponent *uic;
 	GeditDocument *doc;
+	GeditMDI *mdi;
 	
 	gedit_debug (DEBUG_PLUGINS, "");
 	
 	g_return_val_if_fail (window != NULL, PLUGIN_ERROR);
 
+	mdi = gedit_get_mdi ();
+	g_return_val_if_fail (window != NULL, PLUGIN_ERROR);
+
 	uic = gedit_get_ui_component_from_window (window);
 
 	doc = gedit_get_active_document ();
 
-	if ((doc == NULL) || (gedit_document_is_readonly (doc)))		
+	if ((doc == NULL) || (gedit_document_is_readonly (doc)) || (gedit_mdi_get_state (mdi) != GEDIT_STATE_NORMAL))		
 		gedit_menus_set_verb_sensitive (uic, "/commands/" MENU_ITEM_NAME, FALSE);
 	else
 		gedit_menus_set_verb_sensitive (uic, "/commands/" MENU_ITEM_NAME, TRUE);
@@ -144,12 +168,7 @@ init (GeditPlugin *pd)
 {
 	/* initialize */
 	gedit_debug (DEBUG_PLUGINS, "");
-     
-	pd->name = _("User name");
-	pd->desc = _("Inserts the user name at the cursor position.");
-	pd->author = "Paolo Maggi <maggi@athena.polito.it>";
-	pd->copyright = _("Copyright (C) 2002 - Paolo Maggi");
-	
+
 	pd->private_data = NULL;
 		
 	return PLUGIN_OK;
