@@ -32,6 +32,7 @@
 #endif
 
 #include <string.h>
+#include <time.h>
 
 #include <glade/glade-xml.h>
 #include <libgnome/gnome-i18n.h>
@@ -39,8 +40,6 @@
 #include <libgnome/gnome-help.h>
 #include <libgnome/gnome-config.h>
 
-#include <time.h>
-
 #include <gedit/gedit-plugin.h>
 #include <gedit/gedit-debug.h>
 #include <gedit/gedit-menus.h>
@@ -63,14 +62,15 @@
 
 enum
 {
-  COLUMN_FORMATS = 0,
-  COLUMN_INDEX,
-  NUM_COLUMNS
+	COLUMN_FORMATS = 0,
+	COLUMN_INDEX,
+	NUM_COLUMNS
 };
 
 typedef struct _TimeConfigureDialog TimeConfigureDialog;
 
-struct _TimeConfigureDialog {
+struct _TimeConfigureDialog
+{
 	GtkWidget *dialog;
 
 	GtkWidget *list;
@@ -85,7 +85,8 @@ struct _TimeConfigureDialog {
 
 typedef struct _ChoseFormatDialog ChoseFormatDialog;
 
-struct _ChoseFormatDialog {
+struct _ChoseFormatDialog
+{
 	GtkWidget *dialog;
 
 	GtkWidget *list;
@@ -97,7 +98,6 @@ struct _ChoseFormatDialog {
 	GtkWidget *custom_format_example;
 };
 
-
 static gchar *formats[] =
 {
 	"%c",
@@ -134,7 +134,6 @@ static gchar *formats[] =
 	NULL
 };
 
-
 typedef enum 
 {
 	PROMPT_FOR_FORMAT = 0,
@@ -294,9 +293,11 @@ get_time (const gchar* format)
   	struct tm *now;
   	size_t out_length = 0;
 	gchar *locale_format;
-  	
+
 	gedit_debug (DEBUG_PLUGINS, "");
 
+	g_return_val_if_fail (format != NULL, NULL);
+
 	if (strlen (format) == 0)
 		return g_strdup (" ");
 
@@ -351,9 +352,10 @@ create_model (GtkWidget *listview, const gchar *sel_format)
 {
 	gint i = 0;
 	GtkListStore *store;
+	GtkTreeSelection *selection;
 	GtkTreeIter iter;
 	gchar *sf;
-	
+
 	gedit_debug (DEBUG_PLUGINS, "");
 
 	/* create list store */
@@ -365,6 +367,12 @@ create_model (GtkWidget *listview, const gchar *sel_format)
 
 	g_object_unref (G_OBJECT (store));
 
+	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (listview));
+	g_return_val_if_fail (selection != NULL, GTK_TREE_MODEL (store));
+
+	/* there should always be one line selected */
+	gtk_tree_selection_set_mode (selection, GTK_SELECTION_BROWSE);
+
 	if (sel_format == NULL)
 		sf = get_selected_format ();
 	else
@@ -376,7 +384,7 @@ create_model (GtkWidget *listview, const gchar *sel_format)
 		gchar *str;
 
 		str = get_time (formats[i]);
-		
+
 		gedit_debug (DEBUG_PLUGINS, "%d : %s", i, str);
 		gtk_list_store_append (store, &iter);
 		gtk_list_store_set (store, &iter,
@@ -384,20 +392,21 @@ create_model (GtkWidget *listview, const gchar *sel_format)
 				    COLUMN_INDEX, i,
 				    -1);
 		g_free (str);	
-		
+
 		if (strncmp (formats[i], sf, strlen (sf)) == 0)
-		{
-			GtkTreeSelection *selection;
-						
-			selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (listview));
-			g_return_val_if_fail (selection != NULL, GTK_TREE_MODEL (store));
 			gtk_tree_selection_select_iter (selection, &iter);
-		}	
 
 		++i;
 	}
-	
-	g_free (sf);	
+
+	/* fall back to selecting the first iter */
+	if (!gtk_tree_selection_get_selected (selection, NULL, NULL))
+	{
+		gtk_tree_model_get_iter_first (GTK_TREE_MODEL (store), &iter);
+		gtk_tree_selection_select_iter (selection, &iter);
+	}
+
+	g_free (sf);
 
 	return GTK_TREE_MODEL (store);
 }
@@ -440,9 +449,6 @@ create_formats_list (GtkWidget *listview, const gchar* sel_format)
 	gedit_debug (DEBUG_PLUGINS, "");
 
 	g_return_if_fail (listview != NULL);
-
-	/* Create model, it also add model to the tree view */
-	create_model (listview, sel_format);
 	
 	/* the Available formats column */
 	cell = gtk_cell_renderer_text_new ();
@@ -450,6 +456,9 @@ create_formats_list (GtkWidget *listview, const gchar* sel_format)
 			"text", COLUMN_FORMATS, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (listview), column);
 
+	/* Create model, it also add model to the tree view */
+	create_model (listview, sel_format);
+
 	g_signal_connect (G_OBJECT (listview), "realize", 
 			G_CALLBACK (scroll_to_selected), NULL);
 
@@ -793,27 +802,22 @@ static void
 time_world_cb (BonoboUIComponent *uic, gpointer user_data, const gchar* verbname)
 {
 	GeditDocument *doc;
-        gint prompt_response;
-	GeditView *view;
+	gint prompt_response;
 	gchar *the_time = NULL;
 	GeditTimePluginPromptType prompt_type;
-	
+
 	gedit_debug (DEBUG_PLUGINS, "");
 
-	view = gedit_get_active_view ();
-	g_return_if_fail (view != NULL);
-	
-	doc = gedit_view_get_document (view);
+	doc = gedit_get_active_document ();
 	g_return_if_fail (doc != NULL);
 
 	prompt_type = get_prompt_type ();
-	
+
         if (prompt_type == USE_CUSTOM_FORMAT)
         {
 		gchar *cf = get_custom_format ();
 	        the_time = get_time (cf);
 		g_free (cf);
-
 	}
         else if (prompt_type == USE_SELECTED_FORMAT)
         {
@@ -824,31 +828,44 @@ time_world_cb (BonoboUIComponent *uic, gpointer user_data, const gchar* verbname
         else
         {
 		ChoseFormatDialog *dialog;
-		
+		GError *error = NULL;
+
 		BonoboWindow *aw = gedit_get_active_window ();
 		g_return_if_fail (aw != NULL);
 
 		dialog = get_chose_format_dialog (GTK_WINDOW (aw));
 		g_return_if_fail (dialog != NULL);
 
-		prompt_response = gtk_dialog_run (GTK_DIALOG (dialog->dialog));
-
-		switch (prompt_response)
+		do
 		{
+			prompt_response = gtk_dialog_run (GTK_DIALOG (dialog->dialog));
+
+			switch (prompt_response)
+			{
+			case GTK_RESPONSE_HELP:
+				gnome_help_display ("gedit.xml","gedit-insert-date-time-plugin",
+						    &error);
+
+				if (error != NULL)
+				{
+					gedit_warning (GTK_WINDOW (dialog->dialog),
+						       error->message);
+
+					g_error_free (error);
+				}
+				continue;
+
 			case GTK_RESPONSE_OK:
 				/* Get the user's chosen format */
-				if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (
-							dialog->use_list)))
+				if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->use_list)))
 				{
 					gint sel_format;
-					
+						
 					sel_format = get_format_from_list (dialog->list);
-					
-					the_time = get_time (formats [sel_format]);
-					
+					the_time = get_time (formats[sel_format]);
+						
 					g_free (dialog_selected_format);		
-					dialog_selected_format =
-					       g_strdup	(formats [sel_format]);
+					dialog_selected_format = g_strdup (formats[sel_format]);
 
 					dialog_prompt_type = USE_SELECTED_FORMAT;
 					set_selected_format (dialog_selected_format);
@@ -856,46 +873,42 @@ time_world_cb (BonoboUIComponent *uic, gpointer user_data, const gchar* verbname
 				else
 				{
 					const gchar *format;
-					
-					format = gtk_entry_get_text (
-								GTK_ENTRY (dialog->custom_entry));
+						
+					format = gtk_entry_get_text (GTK_ENTRY (dialog->custom_entry));
 					the_time = get_time (format);
-					
+
 					g_free (dialog_custom_format);					
 					dialog_custom_format = g_strdup (format);
 
 					dialog_prompt_type = USE_CUSTOM_FORMAT;
 					set_custom_format (dialog_custom_format);
 				}
-						
+
 				gtk_widget_destroy (dialog->dialog);
 				break;
-				
+					
 			case GTK_RESPONSE_CANCEL:
 				gtk_widget_destroy (dialog->dialog);
 				return;
-	           
-			case GTK_RESPONSE_HELP:
-				/* FIXME: help hooks go in here! */
-				gtk_widget_destroy (dialog->dialog);
-		     		return;
-		}
+			}
+
+		} while (prompt_response == GTK_RESPONSE_HELP );
 	}
-   
+
 	g_return_if_fail (the_time != NULL);
 
 	gedit_document_begin_user_action (doc);
-	
-	gedit_document_insert_text_at_cursor (doc, the_time, -1);
-	gedit_document_insert_text_at_cursor (doc, " ", -1);
+
+	gtk_text_buffer_insert_at_cursor (GTK_TEXT_BUFFER (doc), the_time, -1);
+	gtk_text_buffer_insert_at_cursor (GTK_TEXT_BUFFER (doc), " ", -1);
 
 	gedit_document_end_user_action (doc);
 
 	g_free (the_time);
 }
 
-static 
-gint get_format_from_list(GtkWidget *listview)
+static gint
+get_format_from_list (GtkWidget *listview)
 {
 	GtkTreeModel *model;
 	GtkTreeSelection *selection;
